==> haskell-charset-0.3.7.1-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-BgKaI6TQhzNDRvB2SDayf8
key: charset-0.3.7.1-BgKaI6TQhzNDRvB2SDayf8
license: BSD-3-Clause
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
author: Edward Kmett
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
abi: 011f2df7460b425c74d7e734623768ea
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category
import-dirs: /usr/lib/ghc-8.6.5/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/charset-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-BgKaI6TQhzNDRvB2SDayf8
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-8ZrQ9egE3iI6eE18mlHOfc
key: charset-0.3.7.1-8ZrQ9egE3iI6eE18mlHOfc
license: BSD-3-Clause
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
author: Edward Kmett
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
abi: d646106e851b5314cab53aadc20f3a63
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category
import-dirs: /usr/lib/ghc-8.6.5/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/charset-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-8ZrQ9egE3iI6eE18mlHOfc
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
